summaryrefslogtreecommitdiff
path: root/mm/frame_vector.c
diff options
context:
space:
mode:
authorArnaldo Carvalho de Melo <acme@redhat.com>2020-06-17 13:20:14 -0300
committerArnaldo Carvalho de Melo <acme@redhat.com>2020-06-17 13:20:14 -0300
commit08a7c7772b4db0be06e3b27239147c0a36e2a507 (patch)
treeaf653cb85a263ac19334cdaa74ecd58f909c5cef /mm/frame_vector.c
parentb13b04d9382113f787e21c9567a4022fef8697b9 (diff)
parent69119673bd50b176ded34032fadd41530fb5af21 (diff)
Merge remote-tracking branch 'torvalds/master' into perf/urgent
To get some newer headers that got out of sync with the copies in tools/ so that we can try to have the tools/perf/ build clean for v5.8 with fewer pull requests. Signed-off-by: Arnaldo Carvalho de Melo <acme@redhat.com>
Diffstat (limited to 'mm/frame_vector.c')
-rw-r--r--mm/frame_vector.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/mm/frame_vector.c b/mm/frame_vector.c
index 4107dbca0056..10f82d5643b6 100644
--- a/mm/frame_vector.c
+++ b/mm/frame_vector.c
@@ -29,7 +29,7 @@
* different type underlying the specified range of virtual addresses.
* When the function isn't able to map a single page, it returns error.
*
* This function takes care of grabbing mmap_sem as necessary.
*/
int get_vaddr_frames(unsigned long start, unsigned int nr_frames,
unsigned int gup_flags, struct frame_vector *vec)
@@ -48,7 +48,7 @@ int get_vaddr_frames(unsigned long start, unsigned int nr_frames,
start = untagged_addr(start);
- down_read(&mm->mmap_sem);
+ mmap_read_lock(mm);
locked = 1;
vma = find_vma_intersection(mm, start, start + 1);
if (!vma) {
@@ -102,7 +102,7 @@ int get_vaddr_frames(unsigned long start, unsigned int nr_frames,
} while (vma && vma->vm_flags & (VM_IO | VM_PFNMAP));
out:
if (locked)
- up_read(&mm->mmap_sem);
+ mmap_read_unlock(mm);
if (!ret)
ret = -EFAULT;
if (ret > 0)
@@ -29,7 +29,7 @@
* When the function isn't able to map a single page, it returns error.
*
- * This function takes care of grabbing mmap_sem as necessary.
+ * This function takes care of grabbing mmap_lock as necessary.
*/
int get_vaddr_frames(unsigned long start, unsigned int nr_frames,